==> cuenca_validations-2.1.17.dev4-py3-none-any.whl: tests/test_requests.py <==
import pytest
from pydantic import ValidationError

from cuenca_validations.types.enums import SessionType
from cuenca_validations.types.requests import (
    SessionRequest,
    UserTOSAgreementRequest,
)
from cuenca_validations.typing import DictStrAny


@pytest.mark.parametrize('environment', ['stage', 'sandbox', 'api'])
def test_file_cuenca_url(environment: str) -> None:
    request_data: DictStrAny = dict(
        tos_id='TS67dcae8e74e81bba5a77bf47',
        location=(19.432607, -99.133209),
        signature_image_url=(
            f'https://{environment}.cuenca.com/files/EFQL8_ohvoRp-PkOTYgvQYFA'
        ),
    )
    utos = UserTOSAgreementRequest(**request_data)
    assert utos.signature_image_url is not None
    assert utos.signature_image_url.file_id == 'EFQL8_ohvoRp-PkOTYgvQYFA'


def test_file_cuenca_url_invalid() -> None:
    request_data: DictStrAny = dict(
        tos_id='TS67dcae8e74e81bba5a77bf47',
        location=(19.432607, -99.133209),
        signature_image_url=(
            'https://cuenca.com/files/EFQL87ohvoRp-PkOTYgvQYFA/invalid'
        ),
    )
    with pytest.raises(ValidationError):
        UserTOSAgreementRequest(**request_data)


def test_session_request_without_metadata():
    request_data = {
        'user_id': 'USWqY5cvkISJOxHyEKjAKf8w',
        'type': 'session.curp_validation',
    }
    request = SessionRequest(**request_data)
    assert request.type == SessionType.curp_validation
    assert request.user_id == 'USWqY5cvkISJOxHyEKjAKf8w'


def test_session_request_with_resource_id():
    request_data = {
        'user_id': 'USWqY5cvkISJOxHyEKjAKf8w',
        'type': 'session.onboarding_verification',
        'resource_id': 'some_verification_id',
    }
    request = SessionRequest(**request_data)
    assert request.type == SessionType.onboarding_verification
    assert request.user_id == 'USWqY5cvkISJOxHyEKjAKf8w'
    assert request.resource_id
    assert request.resource_id == 'some_verification_id'


def test_metamap_session_request_without_metadata():
    request_data = {
        'user_id': 'USWqY5cvkISJOxHyEKjAKf8w',
        'type': 'session.onboarding_verification',
    }

    with pytest.raises(ValidationError) as exception:
        SessionRequest(**request_data)

    assert 'Resource id expected for this session' in str(exception)

==> cuenca_validations-2.1.24.dev1-py3-none-any.whl: tests/test_requests.py <==
import pytest
from pydantic import ValidationError

from cuenca_validations.types.requests import (
    UserTOSAgreementRequest,
    UserUpdateRequest,
)
from cuenca_validations.typing import DictStrAny


@pytest.mark.parametrize('environment', ['stage', 'sandbox', 'api'])
def test_file_cuenca_url(environment: str) -> None:
    request_data: DictStrAny = dict(
        tos_id='TS67dcae8e74e81bba5a77bf47',
        location=(19.432607, -99.133209),
        signature_image_url=(
            f'https://{environment}.cuenca.com/files/EFQL8_ohvoRp-PkOTYgvQYFA'
        ),
    )
    utos = UserTOSAgreementRequest(**request_data)
    assert utos.signature_image_url is not None
    assert utos.signature_image_url.file_id == 'EFQL8_ohvoRp-PkOTYgvQYFA'


def test_file_cuenca_url_invalid() -> None:
    request_data: DictStrAny = dict(
        tos_id='TS67dcae8e74e81bba5a77bf47',
        location=(19.432607, -99.133209),
        signature_image_url=(
            'https://cuenca.com/files/EFQL87ohvoRp-PkOTYgvQYFA/invalid'
        ),
    )
    with pytest.raises(ValidationError):
        UserTOSAgreementRequest(**request_data)


def test_update_user_requires_at_least_one_param():
    with pytest.raises(ValueError) as ex:
        UserUpdateRequest()
    assert 'At least one parameter must be provided' in str(ex.value)


def test_extra_params_are_not_allowed():
    with pytest.raises(ValueError) as ex:
        UserUpdateRequest(foo='bar')
    assert 'Extra inputs are not permitted' in str(ex.value)


def test_update_user_update_govt() -> None:
    govt_id: DictStrAny = {
        "govt_id": {"type": "ine", "uri_front": "files/123"}
    }
    with pytest.raises(ValueError) as ex:
        UserUpdateRequest(**govt_id)
    assert 'uri_back must be provided for type ine' in str(ex.value)
